# Keras DropBlock

[![Travis](https://travis-ci.org/CyberZHG/keras-drop-block.svg)](https://travis-ci.org/CyberZHG/keras-drop-block)
[![Coverage](https://coveralls.io/repos/github/CyberZHG/keras-drop-block/badge.svg?branch=master)](https://coveralls.io/github/CyberZHG/keras-drop-block)

Implementation of [DropBlock](https://arxiv.org/pdf/1810.12890.pdf)

## Install

```bash
pip install keras-drop-block
```

## Usage

See [fashion mnist demo](./demo/mnist.py).
